******************
Function Reference
******************

Somoclu Class
=============
.. autoclass:: somoclu.Somoclu
   :members: load_bmus, load_umatrix, load_codebook, train, update_data, view_component_planes, view_umatrix
